﻿using System;
using System.Collections.Generic;
using System.Xml;
using System.Xml.Schema;

namespace BlockingNullObjectChecker
{
    public class DocumentReaderV2
    {
        private readonly ILogger _logger;

        public DocumentReaderV2(ILogger logger)
        {
            if (logger == null) throw new ArgumentNullException("logger");
            _logger = logger;
        }

        public void Read(XmlDocument document)
        {
            if (document == null) throw new ArgumentNullException("document");
            var books = document.SelectNodes("catalog/book");
            if (books == null) throw new XmlSchemaException("The catalog/book node is missing.");

            _logger.Log(string.Format("Book titles: {0}.", string.Join(",", GetBookTitles(document))));

            // Implement your code here
        }

        private static IEnumerable<string> GetBookTitles(XmlNode document)
        {
            var titlesNodes = document.SelectNodes("catalog/book/title");
            if (titlesNodes == null) yield break;
            foreach (XmlElement title in titlesNodes)
            {
                yield return title.InnerText;
            }
        }
    }
}
